from mock import patch, Mock

from django.test import TestCase
from django.test.client import RequestFactory

from tsuru_dashboard import settings
from tsuru_dashboard.services.views import ServiceInstanceDetail


class ServiceInstanceDetailViewTest(TestCase):
    def setUp(self):
        self.request = RequestFactory().get("/")
        self.request.session = {"tsuru_token": "admin"}

    @patch("tsuru_dashboard.services.views.ServiceInstanceDetail.apps")
    @patch("requests.get")
    def test_get_instance_data(self, get, apps):
        data = {u'Name': u'instance'}
        response_mock = Mock(status_code=200)
        response_mock.json.return_value = data
        get.return_value = response_mock

        response = ServiceInstanceDetail.as_view()(self.request, service="service",
                                                   instance="instance")

        self.assertIn("services/detail.html", response.template_name)
        self.assertDictEqual({u"Name": "instance"}, response.context_data['instance'])
        url = '{}/services/{}/instances/{}'.format(settings.TSURU_HOST, "service", "instance")
        get.assert_called_with(url, headers={'authorization': 'admin'})

    @patch("tsuru_dashboard.services.views.ServiceInstanceDetail.get_instance")
    @patch("requests.get")
    def test_get_apps(self, get, get_instance):
        instance_mock = {'Apps': ["ble"]}
        get_instance.return_value = instance_mock
        response_mock = Mock(status_code=200)
        response_mock.json.return_value = [
            {u'name': u'app1'},
            {u'name': u'ble'},
            {u'name': u'app2'}
        ]
        get.return_value = response_mock

        response = ServiceInstanceDetail.as_view()(self.request, service="service",
                                                   instance="instance")

        self.assertIn("services/detail.html", response.template_name)
        self.assertIn("apps", response.context_data)
        expected = ["app1", "app2"]
        self.assertListEqual(expected, response.context_data["apps"])
        url = '{}/apps'.format(settings.TSURU_HOST)
        get.assert_called_with(url, headers={'authorization': 'admin'})



from mock import patch, Mock

from django.test import TestCase
from django.test.client import RequestFactory

from tsuru_dashboard import settings
from tsuru_dashboard.admin.views import ListHealing


class ListHealingViewTest(TestCase):
    def setUp(self):
        self.request = RequestFactory().get("/")
        self.request.session = {"tsuru_token": "admin"}

    @patch("requests.get")
    @patch("tsuru_dashboard.auth.views.token_is_valid")
    def test_should_use_list_template(self, token_is_valid, get):
        token_is_valid.return_value = True
        response_mock = Mock()
        response_mock.json.return_value = []
        get.return_value = response_mock
        response = ListHealing.as_view()(self.request)
        self.assertIn("docker/list_healing.html", response.template_name)
        expected = []
        self.assertListEqual(expected, response.context_data["events"])
        get.assert_called_with(
            "{0}/docker/healing".format(settings.TSURU_HOST),
            headers={"authorization": "admin"}
        )

    @patch("requests.get")
    @patch("tsuru_dashboard.auth.views.token_is_valid")
    def test_null_events(self, token_is_valid, get):
        token_is_valid.return_value = True
        response_mock = Mock(status_code=204)
        get.return_value = response_mock
        response = ListHealing.as_view()(self.request)
        self.assertIn("docker/list_healing.html", response.template_name)
        expected = []
        self.assertListEqual(expected, response.context_data["events"])
        get.assert_called_with(
            "{0}/docker/healing".format(settings.TSURU_HOST),
            headers={"authorization": "admin"}
        )



from django.test import TestCase
from django.test.client import RequestFactory
from django.http import Http404

from tsuru_dashboard import settings
from tsuru_dashboard.apps.views import AppDetailJson

from mock import patch

import json
import httpretty


class AppDetailJsonTestCase(TestCase):
    def setUp(self):
        self.maxDiff = None
        request = RequestFactory().get("/")
        request.session = {"tsuru_token": "admin"}
        self.request = request

    @httpretty.activate
    @patch("tsuru_dashboard.auth.views.token_is_valid")
    def test_view(self, token_is_valid):
        token_is_valid.return_value = True

        url = '{}/docker/node/apps/{}/containers'.format(settings.TSURU_HOST, "app1")
        body = json.dumps([])
        httpretty.register_uri(httpretty.GET, url, body=body, status=200)

        data = {
            "name": "app1",
            "framework": "php",
            "repository": "git@git.com:php.git",
            "state": "dead",
            "units": [
                {"Ip": "10.10.10.10", "Status": "started", "ProcessName": "web", "Name": "xpto"},
                {"Ip": "9.9.9.9", "Status": "stopped", "ProcessName": "worker", "Name": "unitx"},
            ],
            "teams": ["tsuruteam", "crane"]
        }

        url = '{}/apps/{}'.format(settings.TSURU_HOST, "app1")
        body = json.dumps(data)
        httpretty.register_uri(httpretty.GET, url, body=body, status=200)

        response = AppDetailJson.as_view()(self.request, app_name="app1")

        expected = {
            u'app': {
                u'name': u'app1',
                u'repository': u'git@git.com:php.git',
                u'teams': [u'tsuruteam', u'crane'],
                u'framework': u'php',
                u'state': u'dead',
                u'units': [
                    {u'Status': u'started', u'Ip': u'10.10.10.10', u'Name': u'xpto', u'ProcessName': u'web'},
                    {u'Status': u'stopped', u'Ip': u'9.9.9.9', u'Name': u'unitx', u'ProcessName': u'worker'}
                ]
            },
            u'process_list': [u'web', u'worker'],
            u'units_by_status': {
                u'started': [
                    {u'Status': u'started', u'Ip': u'10.10.10.10', u'Name': u'xpto', u'ProcessName': u'web'}
                ],
                u'stopped': [
                    {u'Status': u'stopped', u'Ip': u'9.9.9.9', u'Name': u'unitx', u'ProcessName': u'worker'}
                ]
            }
        }
        self.assertDictEqual(expected, json.loads(response.content))

    @httpretty.activate
    @patch("tsuru_dashboard.auth.views.token_is_valid")
    def test_not_found(self, token_is_valid):
        token_is_valid.return_value = True

        request = RequestFactory().get("/")
        request.session = {"tsuru_token": "admin"}

        url = '{}/apps/{}'.format(settings.TSURU_HOST, "app1")
        httpretty.register_uri(httpretty.GET, url, status=404)

        with self.assertRaises(Http404):
            AppDetailJson.as_view()(request, app_name="app1")

    @httpretty.activate
    @patch("tsuru_dashboard.auth.views.token_is_valid")
    def test_view_get_contaienrs_not_200(self, token_is_valid):
        token_is_valid.return_value = True

        url = '{}/docker/node/apps/{}/containers'.format(settings.TSURU_HOST, "app1")
        httpretty.register_uri(httpretty.GET, url, status=403)

        data = {
            "name": "app1",
            "framework": "php",
            "repository": "git@git.com:php.git",
            "state": "dead",
            "units": [
                {"Ip": "10.10.10.10", "Status": "started", "ProcessName": "web", "Name": "xpto"},
                {"Ip": "9.9.9.9", "Status": "stopped", "ProcessName": "worker", "Name": "unitx"},
            ],
            "teams": ["tsuruteam", "crane"]
        }

        url = '{}/apps/{}'.format(settings.TSURU_HOST, "app1")
        body = json.dumps(data)
        httpretty.register_uri(httpretty.GET, url, body=body, status=200)

        response = AppDetailJson.as_view()(self.request, app_name="app1")

        expected = {
            u'app': {
                u'name': u'app1',
                u'repository': u'git@git.com:php.git',
                u'teams': [u'tsuruteam', u'crane'],
                u'framework': u'php',
                u'state': u'dead',
                u'units': [
                    {u'Status': u'started', u'Ip': u'10.10.10.10', u'Name': u'xpto', u'ProcessName': u'web'},
                    {u'Status': u'stopped', u'Ip': u'9.9.9.9', u'Name': u'unitx', u'ProcessName': u'worker'}
                ]
            },
            u'process_list': [u'web', u'worker'],
            u'units_by_status': {
                u'started': [
                    {u'Status': u'started', u'Ip': u'10.10.10.10', u'Name': u'xpto', u'ProcessName': u'web'}
                ],
                u'stopped': [
                    {u'Status': u'stopped', u'Ip': u'9.9.9.9', u'Name': u'unitx', u'ProcessName': u'worker'}
                ]
            }
        }
        self.assertDictEqual(expected, json.loads(response.content))



from django.test import TestCase
from django.forms import CharField, Textarea

from tsuru_dashboard.auth import forms


class KeysAddFormTest(TestCase):
    def test_forms_should_have_KeyForm(self):
        self.assertTrue(hasattr(forms, 'KeyForm'))

    def test_should_have_key_field(self):
        self.assertIn('key', forms.KeyForm.base_fields)

    def test_key_should_has_a_CharField(self):
        field = forms.KeyForm.base_fields['key']
        self.assertIsInstance(field, CharField)

    def test_should_have_name_field(self):
        self.assertIn('name', forms.KeyForm.base_fields)

    def test_name_should_has_a_CharField(self):
        field = forms.KeyForm.base_fields['name']
        self.assertIsInstance(field, CharField)

    def test_key_should_be_a_TextArea(self):
        field = forms.KeyForm.base_fields['key']
        self.assertIsInstance(field.widget, Textarea)



import os


TSURU_HOST = os.environ.get("TSURU_HOST", "http://localhost:8080")
ELASTICSEARCH_HOST = os.environ.get("ELASTICSEARCH_HOST")
PROMETHEUS_HOST = os.environ.get("PROMETHEUS_HOST")
ELASTICSEARCH_INDEX = os.environ.get("ELASTICSEARCH_INDEX", ".measure-tsuru")
METRICS_COMPONENTS = os.environ.get("METRICS_COMPONENTS", "registry, big-sibling")



from mock import patch, Mock

from django.test import TestCase
from django.test.client import RequestFactory

from tsuru_dashboard.apps.views import LogStream


class LogTest(TestCase):
    @patch("requests.get")
    @patch("tsuru_dashboard.auth.views.token_is_valid")
    def test_log(self, token_is_valid, get):
        def stream():
            yield "message"

        iter_lines = Mock()
        iter_lines.return_value = stream

        token_is_valid.return_value = True
        get.iter_lines.return_value = iter_lines

        self.request = RequestFactory().get("/apps/app-teste/log/")
        self.request.session = {'tsuru_token': 'tokentest'}
        self.app_name = 'app-teste'

        LogStream.as_view()(self.request, app_name=self.app_name)



from mock import patch

from django.test import TestCase
from django.test.client import RequestFactory

import httpretty

from tsuru_dashboard import settings
from tsuru_dashboard.admin.views import NodeAdd

import json


class NodeAddViewTest(TestCase):
    def setUp(self):
        httpretty.enable()

    def tearDown(self):
        httpretty.disable()
        httpretty.reset()

    @patch("tsuru_dashboard.auth.views.token_is_valid")
    def test_view_register_false(self, token_is_valid):
        token_is_valid.return_value = True

        factory = RequestFactory()
        request = factory.post('/', data={"key": "value", "register": "false"})
        request.session = {'tsuru_token': 'tokentest'}

        url = "{}/docker/node".format(settings.TSURU_HOST)
        httpretty.register_uri(
            httpretty.POST,
            url,
            body=json.dumps({"Message": "", "Error": ""}),
            status=200
        )

        response = NodeAdd.as_view()(request)

        self.assertEqual(response.status_code, 200)
        self.assertIn("register", httpretty.last_request().parsed_body)
        self.assertEqual("false", httpretty.last_request().parsed_body["register"][0])
        self.assertIn("key", httpretty.last_request().parsed_body)
        self.assertEqual("value", httpretty.last_request().parsed_body["key"][0])

    @patch("tsuru_dashboard.auth.views.token_is_valid")
    def test_view_register_true(self, token_is_valid):
        token_is_valid.return_value = True

        factory = RequestFactory()
        request = factory.post('/', data={"key": "value", "register": "true"})
        request.session = {'tsuru_token': 'tokentest'}

        url = "{}/docker/node".format(settings.TSURU_HOST)

        httpretty.register_uri(
            httpretty.POST,
            url,
            body=json.dumps({"Message": "", "Error": ""}),
            status=200
        )

        response = NodeAdd.as_view()(request)

        self.assertEqual(response.status_code, 200)
        self.assertIn("register", httpretty.last_request().parsed_body)
        self.assertEqual("true", httpretty.last_request().parsed_body["register"][0])
        self.assertIn("key", httpretty.last_request().parsed_body)
        self.assertEqual("value", httpretty.last_request().parsed_body["key"][0])



from django.test import TestCase

from tsuru_dashboard.metrics.backends.elasticsearch import AppBackend
from tsuru_dashboard.metrics.backends.elasticsearch import ElasticSearch, AppFilter, TsuruMetricsBackend, NodeMetricsBackend
from tsuru_dashboard.metrics.backends.elasticsearch import NET_AGGREGATION, NodesMetricsBackend

from mock import patch, Mock
import datetime
import json


class AppBackendTest(TestCase):
    @patch("requests.get")
    def test_envs_from_api(self, get_mock):
        response_mock = Mock(status_code=200)
        response_mock.json.return_value = {
            "METRICS_BACKEND": "logstash",
            "METRICS_ELASTICSEARCH_HOST": "http://easearch.com",
            "METRICS_LOGSTASH_HOST": "logstash.com"
        }
        get_mock.return_value = response_mock

        app = {"name": "appname", "units": [{"ProcessName": "web"}]}

        backend = AppBackend(app, url="http://easearch.com")
        self.assertIsInstance(backend, ElasticSearch)

    @patch("requests.get")
    def test_envs_from_app(self, get_mock):
        get_mock.return_value = Mock(status_code=500)

        app = {"name": "appname", "envs": {"ELASTICSEARCH_HOST": "ble"}, "units": [{"ID": "id"}]}

        backend = AppBackend(app, 'token')
        self.assertIsInstance(backend, ElasticSearch)


class TsuruMetricsBackendTest(TestCase):
    def test_setup_backend(self):
        backend = TsuruMetricsBackend(filter=AppFilter(app="app_name"), date_range=u'2h')
        self.assertEqual(backend.filtered_query, AppFilter(app="app_name").query())
        self.assertEqual(backend.date_range, u'2h')


class NodesMetricsBackendTest(TestCase):
    def setUp(self):
        self.backend = NodesMetricsBackend(addrs=["127.0.0.1", "128.0.0.1"])
        self.index = ".measure-tsuru-{}*".format(datetime.datetime.utcnow().strftime("%Y.%m.%d"))
        self.aggregation = {
            "addrs": {
                "terms": {
                    "field": "addr.raw",
                    "include": "127.0.0.1|128.0.0.1",
                    "size": 2
                },
                "aggs": {"avg": {"avg": {"field": "value"}}}
            }
        }

        self.net_aggregation = {
            "addrs": {
                "terms": {
                    "field": "addr.raw",
                    "include": "127.0.0.1|128.0.0.1",
                    "size": 2
                },
                "aggs": NET_AGGREGATION["units"]["aggs"]
            }
        }

    @patch("requests.post")
    def test_cpu_max(self, post_mock):
        self.backend.cpu_max()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_cpu_busy")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=self.aggregation)))

    @patch("requests.post")
    def test_cpu_wait(self, post_mock):
        self.backend.cpu_wait()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_cpu_wait")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=self.aggregation)))

    @patch("requests.post")
    def test_load(self, post_mock):
        self.backend.load1()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_load1")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=self.aggregation)))

        self.backend.load5()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_load5")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=self.aggregation)))

        self.backend.load15()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_load15")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=self.aggregation)))

    @patch("requests.post")
    def test_mem_max(self, post_mock):
        self.backend.mem_max()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_mem_used")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=self.aggregation)))

    @patch("requests.post")
    def test_swap(self, post_mock):
        self.backend.swap()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_swap_used")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=self.aggregation)))

    @patch("requests.post")
    def test_disk(self, post_mock):
        self.backend.disk()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_disk_used")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=self.aggregation)))

    @patch("requests.post")
    def test_nettx(self, post_mock):
        self.backend.nettx()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_nettx")
        post_mock.assert_called_with(url, data=json.dumps(
            self.backend.query(aggregation=self.net_aggregation)))

    @patch("requests.post")
    def test_netrx(self, post_mock):
        self.backend.netrx()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_netrx")
        post_mock.assert_called_with(url, data=json.dumps(
            self.backend.query(aggregation=self.net_aggregation)))

    def test_process(self):
        data = {
            "hits": {
                "hits": [],
                "total": 899,
                "max_score": 0.0
            },
            "_shards": {
                "successful": 2,
                "failed": 0,
                "total": 2
            },
            "took": 1400,
            "aggregations": {
                "date": {
                    "buckets": [{
                        "addrs": {
                            "buckets": [{
                                "avg": {"value": 10.1},
                                "key": "127.0.0.1",
                                "doc_count": 15
                            }, {
                                "avg": {"value": 9.2},
                                "key": "128.0.0.1",
                                "doc_count": 15
                            }],
                            "sum_other_doc_count": 0,
                            "doc_count_error_upper_bound": 0
                        },
                        "key_as_string": "2015-07-21T19:35:00.000Z",
                        "key": 1437507300000,
                        "doc_count": 15
                    }, {
                        "addrs": {
                            "buckets": [{
                                "avg": {"value": 10},
                                "key": "127.0.0.1",
                                "doc_count": 15
                            }, {
                                "avg": {"value": 9.5},
                                "key": "128.0.0.1",
                                "doc_count": 15
                            }],
                            "sum_other_doc_count": 0,
                            "doc_count_error_upper_bound": 0
                        },
                        "key_as_string": "2015-07-21T19:36:00.000Z",
                        "key": 1437507360000,
                        "doc_count": 15
                    }]
                }
            }
        }
        expected = {
            "data": {
                "127.0.0.1": [[1437507300000, 20.2], [1437507360000, 20]],
                "128.0.0.1": [[1437507300000, 18.4], [1437507360000, 19]],
            },
            "min": 0,
            "max": 1
        }
        d = self.backend.process(data=data, formatter=lambda x: x * 2)
        self.assertDictEqual(d, expected)


class NodeMetricsBackendTest(TestCase):
    def setUp(self):
        self.backend = NodeMetricsBackend(addr="127.0.0.1")
        self.index = ".measure-tsuru-{}*".format(datetime.datetime.utcnow().strftime("%Y.%m.%d"))

    @patch("requests.post")
    def test_nettx(self, post_mock):
        self.backend.nettx()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_nettx")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=NET_AGGREGATION)))

    @patch("requests.post")
    def test_netrx(self, post_mock):
        self.backend.netrx()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_netrx")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=NET_AGGREGATION)))

    @patch("requests.post")
    def test_mem_max(self, post_mock):
        self.backend.process = Mock()
        self.backend.mem_max()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_mem_used")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query()))

    @patch("requests.post")
    def test_cpu_max(self, post_mock):
        aggregation = {
            "stats": {
                "terms": {"field": "_type"},
                "aggs": {"stats": {"stats": {"field": "value"}}}
            }
        }
        self.backend.cpu_max()
        url = "{}/{}/{}/_search".format(
            self.backend.url, self.index, "host_cpu_user,host_cpu_sys,host_cpu_wait")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=aggregation)))

    @patch("requests.post")
    def test_load(self, post_mock):
        aggregation = {
            "stats": {
                "terms": {"field": "_type"},
                "aggs": {"stats": {"stats": {"field": "value"}}}
            }
        }
        self.backend.load()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_load1,host_load5,host_load15")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=aggregation)))

    @patch("requests.post")
    def test_swap(self, post_mock):
        aggregation = {
            "stats": {
                "terms": {"field": "_type"},
                "aggs": {"stats": {"stats": {"field": "value"}}}
            }
        }
        self.backend.swap()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_swap_used,host_swap_total")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=aggregation)))

    @patch("requests.post")
    def test_disk(self, post_mock):
        aggregation = {
            "stats": {
                "terms": {"field": "_type"},
                "aggs": {"stats": {"stats": {"field": "value"}}}
            }
        }
        self.backend.disk()
        url = "{}/{}/{}/_search".format(self.backend.url, self.index, "host_disk_used,host_disk_total")
        post_mock.assert_called_with(url, data=json.dumps(self.backend.query(aggregation=aggregation)))

    def test_load_process(self):
        data = {
            "took": 86,
            "timed_out": False,
            "_shards": {
                "total": 266,
                "successful": 266,
                "failed": 0
            },
            "hits": {
                "total": 644073,
                "max_score": 0,
                "hits": []
            },
            "aggregations": {
                "date": {
                    "buckets": [
                        {
                            "key_as_string": "2015-07-21T19:35:00.000Z",
                            "key": 1437507300000,
                            "doc_count": 9,
                            "stats": {
                                "buckets": [
                                    {
                                        "stats": {
                                            "avg": 0.021
                                        },
                                        "key": "host_load1"
                                    },
                                    {
                                        "stats": {
                                            "avg": 0.025
                                        },
                                        "key": "host_load5"
                                    },
                                    {
                                        "stats": {
                                            "avg": 0.015
                                        },
                                        "key": "host_load15"
                                    }
                                ]
                            }
                        },
                        {
                            "key_as_string": "2015-07-21T19:36:00.000Z",
                            "key": 1437507360000,
                            "doc_count": 9,
                            "stats": {
                                "buckets": [
                                    {
                                        "stats": {
                                            "avg": 0.020
                                        },
                                        "key": "host_load1"
                                    },
                                    {
                                        "stats": {
                                            "avg": 0.026
                                        },
                                        "key": "host_load5"
                                    },
                                    {
                                        "stats": {
                                            "avg": 0.014
                                        },
                                        "key": "host_load15"
                                    }
                                ]
                            }
                        }
                    ]
                }
            }
        }
        expected = {
            "data": {
                "load1": [[1437507300000, 0.021], [1437507360000, 0.020]],
                "load5": [[1437507300000, 0.025], [1437507360000, 0.026]],
                "load15": [[1437507300000, 0.015], [1437507360000, 0.014]],
            },
            "min": 0,
            "max": 1
        }
        d = self.backend.base_process(data, self.backend.load_process)
        self.assertDictEqual(d, expected)

    def test_cpu_max_process(self):
        data = {
            "took": 86,
            "timed_out": False,
            "_shards": {
                "total": 266,
                "successful": 266,
                "failed": 0
            },
            "hits": {
                "total": 644073,
                "max_score": 0,
                "hits": []
            },
            "aggregations": {
                "date": {
                    "buckets": [
                        {
                            "key_as_string": "2015-07-21T19:35:00.000Z",
                            "key": 1437507300000,
                            "doc_count": 9,
                            "stats": {
                                "buckets": [
                                    {
                                        "stats": {
                                            "avg": 0.021
                                        },
                                        "key": "host_cpu_sys"
                                    },
                                    {
                                        "stats": {
                                            "avg": 0.015
                                        },
                                        "key": "host_cpu_user"
                                    },
                                    {
                                        "stats": {
                                            "avg": 0.001
                                        },
                                        "key": "host_cpu_wait"
                                    }
                                ]
                            }
                        },
                        {
                            "key_as_string": "2015-07-21T19:36:00.000Z",
                            "key": 1437507360000,
                            "doc_count": 9,
                            "stats": {
                                "buckets": [
                                    {
                                        "stats": {
                                            "avg": 0.020
                                        },
                                        "key": "host_cpu_sys"
                                    },
                                    {
                                        "stats": {
                                            "avg": 0.016
                                        },
                                        "key": "host_cpu_user"
                                    },
                                    {
                                        "stats": {
                                            "avg": 0.000
                                        },
                                        "key": "host_cpu_wait"
                                    }
                                ]
                            }
                        }
                    ]
                }
            }
        }
        expected = {
            "data": {
                "sys": [[1437507300000, 2.1], [1437507360000, 2.0]],
                "user": [[1437507300000, 1.5], [1437507360000, 1.6]],
                "wait": [[1437507300000, 0.1], [1437507360000, 0]],
            },
            "min": 0,
            "max": 1
        }
        d = self.backend.base_process(data, self.backend.cpu_max_process)
        self.assertDictEqual(d, expected)



import json
import httpretty
import mock
import base64
import bson

from django.test import TestCase
from django.test.client import RequestFactory

from tsuru_dashboard import settings

from tsuru_dashboard.apps.views import EventInfo


class EventInfoViewTest(TestCase):
    def setUp(self):
        self.request = RequestFactory().get("/?page=2")
        self.request.session = {"tsuru_token": "admin"}
        self.app_name = "appname"

    @httpretty.activate
    @mock.patch("tsuru_dashboard.auth.views.token_is_valid")
    def test_event_info(self, token_is_valid):
        url = '{}/apps/{}'.format(settings.TSURU_HOST, self.app_name)
        httpretty.register_uri(httpretty.GET, url, body="{}", status=200)
        token_is_valid.return_value = True

        event_id = "abc123"
        url = '{}/events/{}'.format(settings.TSURU_HOST, event_id)
        body = json.dumps({
            "StartCustomData": {
                "Data": base64.b64encode(bson.BSON.encode({"start": 1}))
            },
            "EndCustomData": {
                "Data": base64.b64encode(bson.BSON.encode({"end": 1}))
            },
            "OtherCustomData": {
                "Data": base64.b64encode(bson.BSON.encode({"other": 1}))
            }
        })
        httpretty.register_uri(httpretty.GET, url, body=body, status=200)

        response = EventInfo.as_view()(self.request, uuid="abc123", app_name=self.app_name)

        self.assertIn("apps/event.html", response.template_name)
        self.assertIn('event', response.context_data.keys())

    @httpretty.activate
    @mock.patch("tsuru_dashboard.auth.views.token_is_valid")
    def test_event_info_not_found(self, token_is_valid):
        url = '{}/apps/{}'.format(settings.TSURU_HOST, self.app_name)
        httpretty.register_uri(httpretty.GET, url, body="{}", status=200)
        token_is_valid.return_value = True

        event_id = "abc123"
        url = '{}/events/{}'.format(settings.TSURU_HOST, event_id)
        httpretty.register_uri(httpretty.GET, url, status=400)

        response = EventInfo.as_view()(self.request, uuid="abc123", app_name=self.app_name)

        self.assertIn("apps/event.html", response.template_name)
        self.assertIn('event', response.context_data.keys())
